@@ -3,7 +3,7 @@
 // Sumibi Ajax is a client for Sumibi server.
 //
 //   Copyright (C) 2005 ktat atusi@pure.ne.jp
-//     $Date: 2005/07/16 17:41:32 $
+//     $Date: 2005/08/02 00:12:23 $
 //
 // This file is part of Sumibi
 //
@@ -62,19 +62,32 @@ function sumibi_define_candidate(){
     query.value = sumibi.replaceQueryByResult(query.value);
     sumibi.ime.innerHTML = '';
     location.hash = sumibi.hist.length - 1;
-    sumibi.hb.style.display = 'inline';
+    if(sumibi.hb){
+	sumibi.hb.style.display = 'inline';
+    }
 }
 
 function sumibi_forward(){
     var h = location.hash;
     h = h.replace(/^#/,'') - 0;
     location.hash = sumibi.forward(h);
+    sumibi_spacer();
 }
 
 function sumibi_backward(){
     var h = location.hash;
     h = h.replace(/^#/,'') - 0;
     location.hash = sumibi.backward(h);
+    sumibi_spacer();
+}
+
+function sumibi_spacer(){
+    //    alert(sumibi.hf.style.display == 'none');
+    if(sumibi.hb.style.display == 'none' || sumibi.hf.style.display == 'none'){
+	sumibi.hs.style.display = 'inline';
+    }else{
+	sumibi.hs.style.display = 'none';
+    }
 }
 
 //**************************************************************
