@@ -5,7 +5,7 @@
 ;;   Copyright (C) 2002,2003,2004,2005 Kiyoka Nishyama
 ;;   This program was derived from yc.el-4.0.13(auther: knak)
 ;;
-;;     $Date: 2005/07/23 12:57:45 $
+;;     $Date: 2005/08/28 09:59:18 $
 ;;
 ;; This file is part of Sumibi
 ;;
@@ -26,26 +26,12 @@
 
 ;;;     $BG[I[>r7o(B: GPL
 ;;; $B:G?7HGG[I[85(B: http://sourceforge.jp/projects/sumibi/
-
-;;; $BK\%P!<%8%g%s$O%F%9%HHG$G$9!#(B
-;;; $B%P!<%8%g%s7ONs(B 0.3.x $B$G$O$I$s$I$s5!G=DI2C$r9T$J$&$?$aF0:n$,0BDj$7$F$$$J$$2DG=@-$,$"$j$^$9!#(B
-;;; $B0BDj;X8~$NJ}$O(B $B0BDjHG(B (0.2.x) $B$r$4;HMQ$/$@$5$$!#(B
+;;; 
 ;;; $BITL@$JE@$d2~A1$7$?$$E@$,$"$l$P(BSumibi$B$N%a!<%j%s%0%j%9%H$K;22C$7$F%U%#!<%I%P%C%/$r$*$M$,$$$7$^$9!#(B
 ;;;
 ;;; $B$^$?!"(BSumibi$B$K6=L#$r;}$C$F$$$?$@$$$?J}$O$I$J$?$G$b(B
 ;;; $B5$7Z$K%W%m%8%'%/%H$K$4;22C$/$@$5$$!#(B
 ;;;
-;;; $BK\%P!<%8%g%s$K$O<!$N$h$&$J@)8B$,$"$j$^$9!#(B
-;;;   1. $BK\%Q%C%1!<%8$K$O(BEmacs$BMQ$N%/%i%$%"%s%H$N$_4^$^$l$F$$$^$9!#(B
-;;;      1) sumibi.org$B$GF0:n$7$F$$$k(BSumibi Server$B$K@\B3$7$FMxMQ$7$^$9!#(B 
-;;;      2) SSL$B>ZL@=q$r;HMQ$7(BSumibi Server$B$H$NDL?.$r0E9f2=$7$F$$$^$9!#(B
-;;;
-;;;         SSL$B>ZL@=q$O(B GoDaddy$BMM$h$jK\MhM-=~$G$"$k(B Turbo SSL $B$rL5=~Ds6!$7$F$$$?$@$-$^$7$?!#(B
-;;;         https://www.godaddy.com/gdshop/ssl/ssl_opensource.asp?se=%2B
-;;;
-;;;   2. $B%P%0$,$^$@$^$@$"$j$^$9!#(B^_^;
-;;;
-;;;
 ;;; $B%$%s%9%H!<%kJ}K!!";H$$$+$?$O0J2<$N(BWeb$B%5%$%H$K$"$j$^$9$N$G$"$o$;$F;2>H$7$F$/$@$5$$!#(B
 ;;;   http://www.sumibi.org/
 ;;;
@@ -63,7 +49,7 @@
   :group 'input-method
   :group 'Japanese)
 
-(defcustom sumibi-server-url "https://sumibi.org/cgi-bin/sumibi/testing/sumibi.cgi"
+(defcustom sumibi-server-url "https://sumibi.org/cgi-bin/sumibi/stable/sumibi.cgi"
   "Sumibi$B%5!<%P!<$N(BURL$B$r;XDj$9$k!#(B"
   :type  'string
   :group 'sumibi)
@@ -855,7 +841,9 @@ point $B$+$i9TF,J}8~$KF1<o$NJ8;zNs$,B3$/4V$r4A;zJQ49$7$^$9!#(B
 (set-language-info "Japanese" 'input-method "japanese-sumibi")
 (setq default-input-method "japanese-sumibi")
 
-(defconst sumibi-version "0.3.4")
+(defconst sumibi-version
+"0.4.0"
+  )
 (defun sumibi-version (&optional arg)
   "$BF~NO%b!<%IJQ99(B"
   (interactive "P")
